@@ -20,8 +20,6 @@
 
 #include "gtkhtml-editor-private.h"
 
-#include <libgnome/gnome-url.h>
-
 /******************************************************************************
  * Action Group Quick Reference
  *
@@ -286,6 +284,9 @@ action_bold_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	if (gtk_toggle_action_get_active (action))
 		command = "bold-on";
 	else
@@ -694,6 +695,9 @@ action_italic_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	if (gtk_toggle_action_get_active (action))
 		command = "italic-on";
 	else
@@ -861,6 +865,9 @@ action_monospaced_cb (GtkToggleAction *action,
 	GtkHTMLFontStyle and_mask;
 	GtkHTMLFontStyle or_mask;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	if (gtk_toggle_action_get_active (action)) {
 		and_mask = GTK_HTML_FONT_STYLE_MAX;
 		or_mask = GTK_HTML_FONT_STYLE_FIXED;
@@ -957,6 +964,9 @@ action_style_cb (GtkRadioAction *action,
 {
 	const gchar *command = NULL;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	switch (gtk_radio_action_get_current_value (current)) {
 		case GTK_HTML_PARAGRAPH_STYLE_NORMAL:
 			command = "style-normal";
@@ -1043,6 +1053,9 @@ action_size_cb (GtkRadioAction *action,
 {
 	const gchar *command = NULL;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	switch (gtk_radio_action_get_current_value (current)) {
 		case GTK_HTML_FONT_STYLE_SIZE_1:
 			command = "size-minus-2";
@@ -1083,6 +1096,9 @@ action_strikethrough_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	if (gtk_toggle_action_get_active (action))
 		command = "strikeout-on";
 	else
@@ -1095,13 +1111,17 @@ static void
 action_test_url_cb (GtkAction *action,
                     GtkhtmlEditor *editor)
 {
+	GtkEntry *entry;
+	GtkWindow *window;
 	const gchar *text;
 
-	text = gtk_entry_get_text (
-		GTK_ENTRY (WIDGET (LINK_PROPERTIES_URL_ENTRY)));
+	entry = GTK_ENTRY (WIDGET (LINK_PROPERTIES_URL_ENTRY));
+	window = GTK_WINDOW (WIDGET (LINK_PROPERTIES_WINDOW));
+
+	text = gtk_entry_get_text (entry);
 
 	if (text != NULL && *text != '\0')
-		gnome_url_show (text, NULL);
+		gtkhtml_editor_show_uri (window, text);
 }
 
 static void
@@ -1110,6 +1130,9 @@ action_underline_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
+	if (editor->priv->ignore_style_change)
+		return;
+
 	if (gtk_toggle_action_get_active (action))
 		command = "underline-on";
 	else
