@@ -27,9 +27,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <gnome.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkbutton.h>
 
 #ifdef G_OS_WIN32
 /* Clashes with objidl.h, which gets included through a chain of includes from libsoup/soup.h */
@@ -664,6 +662,7 @@ object_requested_cmd (GtkHTML *html, GtkHTMLEmbedded *eb, void *data)
 static void
 got_data (SoupSession *session, SoupMessage *msg, gpointer user_data)
 {
+	const gchar *ContentType;
 	GtkHTMLStream *handle = user_data;
 
 	if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
@@ -671,6 +670,13 @@ got_data (SoupSession *session, SoupMessage *msg, gpointer user_data)
 		gtk_html_end (html, handle, GTK_HTML_STREAM_ERROR);
 		return;
 	}
+	/* Enable change content type in engine */
+	gtk_html_set_default_engine(html, TRUE);
+	
+	ContentType = soup_message_headers_get (msg->response_headers, "Content-type");
+
+	if (ContentType != NULL)
+		gtk_html_set_default_content_type (html, ContentType);
 
 	gtk_html_write (html, handle, msg->response_body->data,
 			msg->response_body->length);
@@ -703,7 +709,6 @@ url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle, gpointer d
 				if (nread == -1) {
 					if (errno == EINTR)
 						continue;
-
 					g_warning ("read error: %s", g_strerror (errno));
 					gtk_html_end (html, handle, GTK_HTML_STREAM_ERROR);
 					break;
@@ -789,7 +794,7 @@ go_list_cb (GtkWidget *widget, gpointer data)
 	go_item *item;
 	int num;
 	/* Only if the item was selected, not deselected */
-	if(GTK_CHECK_MENU_ITEM(widget)->active) {
+	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
 
 		go_position = GPOINTER_TO_INT(data);
 
@@ -848,8 +853,7 @@ goto_url(const char *url, int back_or_forward)
 	}
 
 	/* TODO2 gnome_animator_start (GNOME_ANIMATOR (animator)); */
-
-	html_stream_handle = gtk_html_begin_content (html, "text/html; charset=utf-8");
+	html_stream_handle = gtk_html_begin_content (html, (gchar *)gtk_html_get_default_content_type (html));
 
 	/* Yuck yuck yuck.  Well this code is butt-ugly already
 	anyway.  */
@@ -910,6 +914,8 @@ goto_url(const char *url, int back_or_forward)
 		group = NULL;
 
 		for(i=0;i<tmp;i++) {
+			GtkWidget *submenu;
+
 			item = g_list_nth_data(go_list, i);
 			item->widget = gtk_radio_menu_item_new_with_label(group, item->url);
 
@@ -921,7 +927,8 @@ goto_url(const char *url, int back_or_forward)
 			if(i == 0)
 				gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item->widget), TRUE);
 
-			gtk_menu_shell_append (GTK_MENU_SHELL (GTK_MENU_ITEM(main_menu[3].widget)->submenu), item->widget);
+			submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (main_menu[3].widget));
+			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item->widget);
 			gtk_widget_show(item->widget);
 
 		}
@@ -949,29 +956,30 @@ goto_url(const char *url, int back_or_forward)
 static void
 bug_cb (GtkWidget *widget, gpointer data)
 {
-	gchar cwd[PATH_MAX], *filename, *url;
+	gchar *cwd, *filename, *url;
 
-	getcwd(cwd, sizeof (cwd));
+	cwd = g_get_current_dir ();
 	filename = g_strdup_printf("%s/bugs.html", cwd);
 	url = g_filename_to_uri(filename, NULL, NULL);
 	goto_url(url, 0);
 	g_free(url);
 	g_free(filename);
+	g_free(cwd);
 }
 
 static void
 test_cb (GtkWidget *widget, gpointer data)
 {
-	gchar cwd[PATH_MAX], *filename, *url;
+	gchar *cwd, *filename, *url;
 
-	getcwd(cwd, sizeof (cwd));
+	cwd = g_get_current_dir ();
 	filename = g_strdup_printf ("%s/tests/test%d.html", cwd,
 				    GPOINTER_TO_INT (data));
 	url = g_filename_to_uri (filename, NULL, NULL);
-
 	goto_url(url, 0);
 	g_free(url);
 	g_free(filename);
+	g_free(cwd);
 }
 
 static void
